@@ -1,7 +1,4 @@
 from .behaviour import BroadcastBehaviour
 from .schema import ListenerSchema
 
-__all__ = (
-    "BroadcastBehaviour",
-    "ListenerSchema"
-)
\ No newline at end of file
+__all__ = ("BroadcastBehaviour", "ListenerSchema")
