@@ -16,11 +16,7 @@ class BroadcastBehaviour(Behaviour):
 
     def allocate(
         self,
-        cube: Cube[
-            Union[
-                ListenerSchema,
-            ]
-        ],
+        cube: Cube[ListenerSchema],
     ):
         if isinstance(cube.metaclass, ListenerSchema):
             listener = cube.metaclass.build_listener(cube.content, self.broadcast)
@@ -31,7 +27,7 @@ class BroadcastBehaviour(Behaviour):
             return
         return True
 
-    def uninstall(self, cube: Cube) -> Any:
+    def release(self, cube: Cube) -> Any:
         if isinstance(cube.metaclass, ListenerSchema):
             self.broadcast.removeListener(self.broadcast.getListener(cube.content))
         else:
